@@ -17,12 +17,24 @@
 #
 # The bilinear form a(v, u) and linear form L(v) for
 # tensor-weighted Poisson's equation.
-from ufl import (Coefficient, FiniteElement, FunctionSpace, Mesh, TensorElement, TestFunction, TrialFunction,
-                 VectorElement, dx, grad, inner, triangle)
+from ufl import (
+    Coefficient,
+    FunctionSpace,
+    Mesh,
+    TestFunction,
+    TrialFunction,
+    dx,
+    grad,
+    inner,
+    triangle,
+)
+from ufl.finiteelement import FiniteElement
+from ufl.pullback import identity_pullback
+from ufl.sobolevspace import H1, L2
 
-P1 = FiniteElement("Lagrange", triangle, 1)
-P0 = TensorElement("Discontinuous Lagrange", triangle, 0, shape=(2, 2))
-domain = Mesh(VectorElement("Lagrange", triangle, 1))
+P1 = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+P0 = FiniteElement("Discontinuous Lagrange", triangle, 0, (2, 2), identity_pullback, L2)
+domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
 p1_space = FunctionSpace(domain, P1)
 p0_space = FunctionSpace(domain, P0)
 
