@@ -6,38 +6,67 @@ __date__ = "2008-03-12 -- 2009-01-28"
 
 import pytest
 
-from ufl import (Argument, Coefficient, FacetNormal, FiniteElement, FunctionSpace, Mesh, TestFunction, TrialFunction,
-                 VectorElement, adjoint, div, dot, ds, dx, grad, inner, triangle)
-from ufl.algorithms import (expand_derivatives, expand_indices, extract_arguments, extract_coefficients,
-                            extract_elements, extract_unique_elements)
-from ufl.corealg.traversal import post_traversal, pre_traversal, unique_post_traversal, unique_pre_traversal
+from ufl import (
+    Argument,
+    Coefficient,
+    FacetNormal,
+    FunctionSpace,
+    Mesh,
+    TestFunction,
+    TrialFunction,
+    adjoint,
+    div,
+    dot,
+    ds,
+    dx,
+    grad,
+    inner,
+    triangle,
+)
+from ufl.algorithms import (
+    expand_derivatives,
+    expand_indices,
+    extract_arguments,
+    extract_coefficients,
+    extract_elements,
+    extract_unique_elements,
+)
+from ufl.corealg.traversal import (
+    post_traversal,
+    pre_traversal,
+    unique_post_traversal,
+    unique_pre_traversal,
+)
+from ufl.finiteelement import FiniteElement
+from ufl.pullback import identity_pullback
+from ufl.sobolevspace import H1
 
 # TODO: add more tests, covering all utility algorithms
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def element():
-    return FiniteElement("CG", triangle, 1)
+    return FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def domain():
-    return Mesh(VectorElement("CG", triangle, 1))
+    return Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def space(element, domain):
     return FunctionSpace(domain, element)
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def arguments(space):
     v = TestFunction(space)
     u = TrialFunction(space)
     return (v, u)
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def coefficients(space):
     c = Coefficient(space)
     f = Coefficient(space)
@@ -45,10 +74,10 @@ def coefficients(space):
 
 
 @pytest.fixture
-def forms(arguments, coefficients, space):
+def forms(arguments, coefficients, domain):
     v, u = arguments
     c, f = coefficients
-    n = FacetNormal(space)
+    n = FacetNormal(domain)
     a = u * v * dx
     L = f * v * dx
     b = u * v * dx(0) + inner(c * grad(u), grad(v)) * dx(1) + dot(n, grad(u)) * v * ds + f * v * dx
@@ -64,13 +93,13 @@ def test_extract_coefficients_vs_fixture(coefficients, forms):
     assert coefficients == tuple(extract_coefficients(forms[2]))
 
 
-def test_extract_elements_and_extract_unique_elements(forms, domain):
+def test_extract_elements_and_extract_unique_elements(forms, element, domain):
     b = forms[2]
     integrals = b.integrals_by_type("cell")
     integrals[0].integrand()
 
-    element1 = FiniteElement("CG", triangle, 1)
-    element2 = FiniteElement("CG", triangle, 1)
+    element1 = element
+    element2 = element
 
     space1 = FunctionSpace(domain, element1)
     space2 = FunctionSpace(domain, element2)
@@ -83,9 +112,7 @@ def test_extract_elements_and_extract_unique_elements(forms, domain):
     assert extract_unique_elements(a) == (element1,)
 
 
-def test_pre_and_post_traversal(domain):
-    element = FiniteElement("CG", "triangle", 1)
-    space = FunctionSpace(domain, element)
+def test_pre_and_post_traversal(space):
     v = TestFunction(space)
     f = Coefficient(space)
     g = Coefficient(space)
@@ -103,13 +130,15 @@ def test_pre_and_post_traversal(domain):
 
 
 def test_expand_indices(domain):
-    element = FiniteElement("Lagrange", triangle, 2)
+    element = FiniteElement("Lagrange", triangle, 2, (), identity_pullback, H1)
     space = FunctionSpace(domain, element)
     v = TestFunction(space)
     u = TrialFunction(space)
 
     def evaluate(form):
-        return form.cell_integral()[0].integrand()((), {v: 3, u: 5})  # TODO: How to define values of derivatives?
+        return form.cell_integral()[0].integrand()(
+            (), {v: 3, u: 5}
+        )  # TODO: How to define values of derivatives?
 
     a = div(grad(v)) * u * dx
     # a1 = evaluate(a)
@@ -124,8 +153,8 @@ def test_expand_indices(domain):
 def test_adjoint(domain):
     cell = triangle
 
-    V1 = FiniteElement("CG", cell, 1)
-    V2 = FiniteElement("CG", cell, 2)
+    V1 = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
+    V2 = FiniteElement("Lagrange", cell, 2, (), identity_pullback, H1)
 
     s1 = FunctionSpace(domain, V1)
     s2 = FunctionSpace(domain, V2)
@@ -139,17 +168,17 @@ def test_adjoint(domain):
     assert u2.number() < v2.number()
 
     a = u * v * dx
-    a_arg_degrees = [arg.ufl_element().degree() for arg in extract_arguments(a)]
+    a_arg_degrees = [arg.ufl_element().embedded_superdegree for arg in extract_arguments(a)]
     assert a_arg_degrees == [2, 1]
 
     b = adjoint(a)
-    b_arg_degrees = [arg.ufl_element().degree() for arg in extract_arguments(b)]
+    b_arg_degrees = [arg.ufl_element().embedded_superdegree for arg in extract_arguments(b)]
     assert b_arg_degrees == [1, 2]
 
     c = adjoint(a, (u2, v2))
-    c_arg_degrees = [arg.ufl_element().degree() for arg in extract_arguments(c)]
+    c_arg_degrees = [arg.ufl_element().embedded_superdegree for arg in extract_arguments(c)]
     assert c_arg_degrees == [1, 2]
 
     d = adjoint(b)
-    d_arg_degrees = [arg.ufl_element().degree() for arg in extract_arguments(d)]
+    d_arg_degrees = [arg.ufl_element().embedded_superdegree for arg in extract_arguments(d)]
     assert d_arg_degrees == [2, 1]
