@@ -1,27 +1,46 @@
 import pytest
 
-from ufl import (Coefficient, Cofunction, FiniteElement, Form, FormSum, FunctionSpace, Mesh, SpatialCoordinate,
-                 TestFunction, TrialFunction, VectorElement, dot, ds, dx, grad, inner, nabla_grad, triangle)
+from ufl import (
+    Coefficient,
+    Cofunction,
+    Form,
+    FormSum,
+    FunctionSpace,
+    Mesh,
+    SpatialCoordinate,
+    TestFunction,
+    TrialFunction,
+    dot,
+    ds,
+    dx,
+    grad,
+    inner,
+    nabla_grad,
+    triangle,
+)
+from ufl.finiteelement import FiniteElement
 from ufl.form import BaseForm
+from ufl.pullback import identity_pullback
+from ufl.sobolevspace import H1
 
 
 @pytest.fixture
 def element():
     cell = triangle
-    element = FiniteElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
     return element
 
 
 @pytest.fixture
 def domain():
     cell = triangle
-    return Mesh(VectorElement("Lagrange", cell, 1))
+    return Mesh(FiniteElement("Lagrange", cell, 1, (2,), identity_pullback, H1))
 
 
 @pytest.fixture
 def mass(domain):
     cell = triangle
-    element = FiniteElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
     space = FunctionSpace(domain, element)
     v = TestFunction(space)
     u = TrialFunction(space)
@@ -31,7 +50,7 @@ def mass(domain):
 @pytest.fixture
 def stiffness(domain):
     cell = triangle
-    element = FiniteElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
     space = FunctionSpace(domain, element)
     v = TestFunction(space)
     u = TrialFunction(space)
@@ -41,7 +60,7 @@ def stiffness(domain):
 @pytest.fixture
 def convection(domain):
     cell = triangle
-    element = VectorElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (2,), identity_pullback, H1)
     space = FunctionSpace(domain, element)
     v = TestFunction(space)
     u = TrialFunction(space)
@@ -52,7 +71,7 @@ def convection(domain):
 @pytest.fixture
 def load(domain):
     cell = triangle
-    element = FiniteElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
     space = FunctionSpace(domain, element)
     f = Coefficient(space)
     v = TestFunction(space)
@@ -62,7 +81,7 @@ def load(domain):
 @pytest.fixture
 def boundary_load(domain):
     cell = triangle
-    element = FiniteElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
     space = FunctionSpace(domain, element)
     f = Coefficient(space)
     v = TestFunction(space)
@@ -71,7 +90,7 @@ def boundary_load(domain):
 
 def test_form_arguments(mass, stiffness, convection, load):
     v, u = mass.arguments()
-    f, = load.coefficients()
+    (f,) = load.coefficients()
 
     assert v.number() == 0
     assert u.number() == 1
@@ -100,8 +119,8 @@ def test_form_coefficients(element, domain):
 
 def test_form_domains():
     cell = triangle
-    domain = Mesh(VectorElement("Lagrange", cell, 1))
-    element = FiniteElement("Lagrange", cell, 1)
+    element = FiniteElement("Lagrange", cell, 1, (), identity_pullback, H1)
+    domain = Mesh(FiniteElement("Lagrange", cell, 1, (2,), identity_pullback, H1))
     V = FunctionSpace(domain, element)
 
     v = TestFunction(V)
@@ -132,33 +151,34 @@ def test_form_integrals(mass, boundary_load):
 
 
 def test_form_call():
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
-    element = FiniteElement("Lagrange", triangle, 1)
+    element = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     V = FunctionSpace(domain, element)
     v = TestFunction(V)
     u = TrialFunction(V)
     f = Coefficient(V)
     g = Coefficient(V)
-    a = g*inner(grad(v), grad(u))*dx
+    a = g * inner(grad(v), grad(u)) * dx
     M = a(f, f, coefficients={g: 1})
-    assert M == grad(f)**2*dx
+    assert M == grad(f) ** 2 * dx
 
     import sys
+
     if sys.version_info.major >= 3 and sys.version_info.minor >= 5:
-        a = u*v*dx
+        a = u * v * dx
         M = eval("(a @ f) @ g")
-        assert M == g*f*dx
+        assert M == g * f * dx
 
 
 def test_formsum(mass):
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
-    element = FiniteElement("Lagrange", triangle, 1)
+    element = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     V = FunctionSpace(domain, element)
     v = Cofunction(V.dual())
 
     assert v + mass
     assert mass + v
-    assert isinstance((mass+v), FormSum)
+    assert isinstance((mass + v), FormSum)
 
     assert len((mass + v + v).components()) == 3
     # Variational forms are summed appropriately
@@ -166,7 +186,7 @@ def test_formsum(mass):
 
     assert v - mass
     assert mass - v
-    assert isinstance((mass+v), FormSum)
+    assert isinstance((mass + v), FormSum)
 
     assert -v
     assert isinstance(-v, BaseForm)
