@@ -8,7 +8,7 @@
 #
 # Modified by Anders Logg, 2008.
 
-from ufl.utils.formatting import lstr, tstr, estr
+from ufl.utils.formatting import estr, lstr, tstr
 
 
 class FormData(object):
@@ -20,9 +20,11 @@ class FormData(object):
     def __str__(self):
         """Return formatted summary of form data."""
         types = sorted(self.max_subdomain_ids.keys())
-        geometry = (("Geometric dimension", self.geometric_dimension), )
-        subdomains = tuple((f"Number of {integral_type} subdomains", self.max_subdomain_ids[integral_type])
-                           for integral_type in types)
+        geometry = (("Geometric dimension", self.geometric_dimension),)
+        subdomains = tuple(
+            (f"Number of {integral_type} subdomains", self.max_subdomain_ids[integral_type])
+            for integral_type in types
+        )
         functions = (
             # Arguments
             ("Rank", self.rank),
