@@ -8,17 +8,15 @@
 #
 # Modified by Anders Logg, 2008
 
-from ufl.core.expr import Expr
-from ufl.integral import Integral
 from ufl.action import Action
 from ufl.adjoint import Adjoint
-from ufl.form import Form, FormSum, BaseForm
+from ufl.core.expr import Expr
+from ufl.form import BaseForm, Form, FormSum
+from ufl.integral import Integral
 
 
-# --- Traversal utilities ---
-
 def iter_expressions(a):
-    """Utility function to handle Form, Integral and any Expr the same way when inspecting expressions.
+    """Handle Form, Integral and any Expr the same way when inspecting expressions.
 
     Returns an iterable over Expr instances:
     - a is an Expr: (a,)
