@@ -7,15 +7,15 @@
 #
 # Modified by Nacime Bouziani, 2021-2022.
 
-from ufl.form import BaseForm
-from ufl.core.ufl_type import ufl_type
 from ufl.argument import Argument
+from ufl.core.ufl_type import ufl_type
+from ufl.form import BaseForm
 from ufl.functionspace import AbstractFunctionSpace
 from ufl.utils.counted import Counted
 
-
 # --- The Matrix class represents a matrix, an assembled two form ---
 
+
 @ufl_type()
 class Matrix(BaseForm, Counted):
     """An assemble linear operator between two function spaces."""
@@ -30,12 +30,12 @@ class Matrix(BaseForm, Counted):
         "_ufl_shape",
         "_arguments",
         "_coefficients",
-        "_domains")
+        "_domains",
+    )
 
     def __getnewargs__(self):
         """Get new args."""
-        return (self._ufl_function_spaces[0], self._ufl_function_spaces[1],
-                self._count)
+        return (self._ufl_function_spaces[0], self._ufl_function_spaces[1], self._count)
 
     def __init__(self, row_space, column_space, count=None):
         """Initialise."""
@@ -53,7 +53,10 @@ class Matrix(BaseForm, Counted):
         self.ufl_operands = ()
         self._domains = None
         self._hash = None
-        self._repr = f"Matrix({self._ufl_function_spaces[0]!r}, {self._ufl_function_spaces[1]!r}, {self._count!r})"
+        self._repr = (
+            f"Matrix({self._ufl_function_spaces[0]!r} "
+            f"{self._ufl_function_spaces[1]!r}, {self._count!r})"
+        )
 
     def ufl_function_spaces(self):
         """Get the tuple of function spaces of this coefficient."""
@@ -61,13 +64,16 @@ class Matrix(BaseForm, Counted):
 
     def _analyze_form_arguments(self):
         """Define arguments of a matrix when considered as a form."""
-        self._arguments = (Argument(self._ufl_function_spaces[0], 0),
-                           Argument(self._ufl_function_spaces[1], 1))
+        self._arguments = (
+            Argument(self._ufl_function_spaces[0], 0),
+            Argument(self._ufl_function_spaces[1], 1),
+        )
         self._coefficients = ()
 
     def _analyze_domains(self):
         """Analyze which domains can be found in a Matrix."""
         from ufl.domain import join_domains
+
         # Collect unique domains
         self._domains = join_domains([fs.ufl_domain() for fs in self._ufl_function_spaces])
 
@@ -95,4 +101,6 @@ class Matrix(BaseForm, Counted):
             return False
         if self is other:
             return True
-        return self._count == other._count and self._ufl_function_spaces == other._ufl_function_spaces
+        return (
+            self._count == other._count and self._ufl_function_spaces == other._ufl_function_spaces
+        )
