@@ -10,16 +10,14 @@
 # Modified by Massimiliano Leoni, 2016.
 
 import numbers
-
 from itertools import chain
 
-from ufl.core.expr import Expr
 from ufl.checks import is_true_ufl_scalar
 from ufl.constantvalue import as_ufl
-from ufl.domain import as_domain, AbstractDomain, extract_domains
+from ufl.core.expr import Expr
+from ufl.domain import AbstractDomain, as_domain, extract_domains
 from ufl.protocols import id_or_none
 
-
 # Export list for ufl.classes
 __all_classes__ = ["Measure", "MeasureSum", "MeasureProduct"]
 
@@ -31,20 +29,22 @@ __all_classes__ = ["Measure", "MeasureSum", "MeasureProduct"]
 _integral_types = [
     # === Integration over full topological dimension:
     ("cell", "dx"),  # Over cells of a mesh
-
     # === Integration over topological dimension - 1:
     ("exterior_facet", "ds"),  # Over one-sided exterior facets of a mesh
     ("interior_facet", "dS"),  # Over two-sided facets between pairs of adjacent cells of a mesh
-
     # === Integration over topological dimension 0
     ("vertex", "dP"),  # Over vertices of a mesh
-
     # === Integration over custom domains
     ("custom", "dc"),  # Over custom user-defined domains (run-time quadrature points)
     ("cutcell", "dC"),  # Over a cell with some part cut away (run-time quadrature points)
-    ("interface", "dI"),  # Over a facet fragment overlapping with two or more cells (run-time quadrature points)
-    ("overlap", "dO"),  # Over a cell fragment overlapping with two or more cells (run-time quadrature points)
-
+    (
+        "interface",
+        "dI",
+    ),  # Over a facet fragment overlapping with two or more cells (run-time quadrature points)
+    (
+        "overlap",
+        "dO",
+    ),  # Over a cell fragment overlapping with two or more cells (run-time quadrature points)
     # === Firedrake specifics:
     ("exterior_facet_bottom", "ds_b"),  # Over bottom facets on extruded mesh
     ("exterior_facet_top", "ds_t"),  # Over top facets on extruded mesh
@@ -75,8 +75,7 @@ def register_integral_type(integral_type, measure_name):
 def as_integral_type(integral_type):
     """Map short name to long name and require a valid one."""
     integral_type = integral_type.replace(" ", "_")
-    integral_type = measure_name_to_integral_type.get(integral_type,
-                                                      integral_type)
+    integral_type = measure_name_to_integral_type.get(integral_type, integral_type)
     if integral_type not in integral_type_to_measure_name:
         raise ValueError("Invalid integral_type.")
     return integral_type
@@ -102,12 +101,14 @@ class Measure(object):
 
     __slots__ = ("_integral_type", "_domain", "_subdomain_id", "_metadata", "_subdomain_data")
 
-    def __init__(self,
-                 integral_type,  # "dx" etc
-                 domain=None,
-                 subdomain_id="everywhere",
-                 metadata=None,
-                 subdomain_data=None):
+    def __init__(
+        self,
+        integral_type,  # "dx" etc
+        domain=None,
+        subdomain_id="everywhere",
+        metadata=None,
+        subdomain_data=None,
+    ):
         """Initialise.
 
         Args:
@@ -123,9 +124,11 @@ class Measure(object):
         self._integral_type = as_integral_type(integral_type)
 
         # Check that we either have a proper AbstractDomain or none
-        self._domain = None if domain is None else as_domain(domain)
-        if not (self._domain is None or isinstance(self._domain, AbstractDomain)):
-            raise ValueError("Invalid domain.")
+        if domain is not None:
+            domain = as_domain(domain)
+            if not isinstance(domain, AbstractDomain):
+                raise ValueError("Invalid domain.")
+        self._domain = domain
 
         # Store subdomain data
         self._subdomain_data = subdomain_data
@@ -177,12 +180,9 @@ class Measure(object):
         """
         return self._metadata
 
-    def reconstruct(self,
-                    integral_type=None,
-                    subdomain_id=None,
-                    domain=None,
-                    metadata=None,
-                    subdomain_data=None):
+    def reconstruct(
+        self, integral_type=None, subdomain_id=None, domain=None, metadata=None, subdomain_data=None
+    ):
         """Construct a new Measure object with some properties replaced with new values.
 
         Example:
@@ -202,9 +202,13 @@ class Measure(object):
             metadata = self.metadata()
         if subdomain_data is None:
             subdomain_data = self.subdomain_data()
-        return Measure(self.integral_type(),
-                       domain=domain, subdomain_id=subdomain_id,
-                       metadata=metadata, subdomain_data=subdomain_data)
+        return Measure(
+            self.integral_type(),
+            domain=domain,
+            subdomain_id=subdomain_id,
+            metadata=metadata,
+            subdomain_data=subdomain_data,
+        )
 
     def subdomain_data(self):
         """Return the integral subdomain_data.
@@ -218,12 +222,18 @@ class Measure(object):
     # Note: Must keep the order of the first two arguments here
     # (subdomain_id, metadata) for backwards compatibility, because
     # some tutorials write e.g. dx(0, {...}) to set metadata.
-    def __call__(self, subdomain_id=None, metadata=None, domain=None,
-                 subdomain_data=None, degree=None, scheme=None):
+    def __call__(
+        self,
+        subdomain_id=None,
+        metadata=None,
+        domain=None,
+        subdomain_data=None,
+        degree=None,
+        scheme=None,
+    ):
         """Reconfigure measure with new domain specification or metadata."""
         # Let syntax dx() mean integral over everywhere
-        all_args = (subdomain_id, metadata, domain, subdomain_data,
-                    degree, scheme)
+        all_args = (subdomain_id, metadata, domain, subdomain_data, degree, scheme)
         if all(arg is None for arg in all_args):
             return self.reconstruct(subdomain_id="everywhere")
 
@@ -231,11 +241,13 @@ class Measure(object):
         # over entire domain.  To do this we need to hijack the first
         # argument:
         if subdomain_id is not None and (
-            isinstance(subdomain_id, AbstractDomain) or hasattr(subdomain_id, 'ufl_domain')
+            isinstance(subdomain_id, AbstractDomain) or hasattr(subdomain_id, "ufl_domain")
         ):
             if domain is not None:
-                raise ValueError("Ambiguous: setting domain both as keyword argument and first argument.")
-            subdomain_id, domain = "everywhere", as_domain(subdomain_id)
+                raise ValueError(
+                    "Ambiguous: setting domain both as keyword argument and first argument."
+                )
+            subdomain_id, domain = "everywhere", subdomain_id
 
         # If degree or scheme is set, inject into metadata. This is a
         # quick fix to enable the dx(..., degree=3) notation.
@@ -250,9 +262,12 @@ class Measure(object):
         # If we get any keywords, use them to reconstruct Measure.
         # Note that if only one argument is given, it is the
         # subdomain_id, e.g. dx(3) == dx(subdomain_id=3)
-        return self.reconstruct(subdomain_id=subdomain_id, domain=domain,
-                                metadata=metadata,
-                                subdomain_data=subdomain_data)
+        return self.reconstruct(
+            subdomain_id=subdomain_id,
+            domain=domain,
+            metadata=metadata,
+            subdomain_data=subdomain_data,
+        )
 
     def __str__(self):
         """Format as a string."""
@@ -268,7 +283,7 @@ class Measure(object):
         if self._subdomain_data is not None:
             args.append("subdomain_data=%s" % (self._subdomain_data,))
 
-        return "%s(%s)" % (name, ', '.join(args))
+        return "%s(%s)" % (name, ", ".join(args))
 
     def __repr__(self):
         """Return a repr string for this Measure."""
@@ -284,17 +299,19 @@ class Measure(object):
         if self._subdomain_data is not None:
             args.append("subdomain_data=%s" % repr(self._subdomain_data))
 
-        r = "%s(%s)" % (type(self).__name__, ', '.join(args))
+        r = "%s(%s)" % (type(self).__name__, ", ".join(args))
         return r
 
     def __hash__(self):
         """Return a hash value for this Measure."""
         metadata_hashdata = tuple(sorted((k, id(v)) for k, v in list(self._metadata.items())))
-        hashdata = (self._integral_type,
-                    self._subdomain_id,
-                    hash(self._domain),
-                    metadata_hashdata,
-                    id_or_none(self._subdomain_data))
+        hashdata = (
+            self._integral_type,
+            self._subdomain_id,
+            hash(self._domain),
+            metadata_hashdata,
+            id_or_none(self._subdomain_data),
+        )
         return hash(hashdata)
 
     def __eq__(self, other):
@@ -302,10 +319,14 @@ class Measure(object):
         sorted_metadata = sorted((k, id(v)) for k, v in list(self._metadata.items()))
         sorted_other_metadata = sorted((k, id(v)) for k, v in list(other._metadata.items()))
 
-        return (isinstance(other, Measure) and self._integral_type == other._integral_type and  # noqa: W504
-                self._subdomain_id == other._subdomain_id and self._domain == other._domain and  # noqa: W504
-                id_or_none(self._subdomain_data) == id_or_none(other._subdomain_data) and  # noqa: W504
-                sorted_metadata == sorted_other_metadata)
+        return (
+            isinstance(other, Measure)
+            and self._integral_type == other._integral_type
+            and self._subdomain_id == other._subdomain_id
+            and self._domain == other._domain
+            and id_or_none(self._subdomain_data) == id_or_none(other._subdomain_data)
+            and sorted_metadata == sorted_other_metadata
+        )
 
     def __add__(self, other):
         """Add two measures (self+other).
@@ -344,8 +365,8 @@ class Measure(object):
         Integration properties are taken from this Measure object.
         """
         # Avoid circular imports
-        from ufl.integral import Integral
         from ufl.form import Form
+        from ufl.integral import Integral
 
         # Allow python literals: 1*dx and 1.0*dx
         if isinstance(integrand, (int, float)):
@@ -361,18 +382,33 @@ class Measure(object):
             raise ValueError(
                 "Can only integrate scalar expressions. The integrand is a "
                 f"tensor expression with value shape {integrand.ufl_shape} and "
-                f"free indices with labels {integrand.ufl_free_indices}.")
+                f"free indices with labels {integrand.ufl_free_indices}."
+            )
 
         # If we have a tuple of domain ids build the integrals one by
         # one and construct as a Form in one go.
         subdomain_id = self.subdomain_id()
         if isinstance(subdomain_id, tuple):
-            return Form(list(chain(*((integrand * self.reconstruct(subdomain_id=d)).integrals()
-                                     for d in subdomain_id))))
+            return Form(
+                list(
+                    chain(
+                        *(
+                            (integrand * self.reconstruct(subdomain_id=d)).integrals()
+                            for d in subdomain_id
+                        )
+                    )
+                )
+            )
 
         # Check that we have an integer subdomain or a string
         # ("everywhere" or "otherwise", any more?)
-        if not isinstance(subdomain_id, (str, numbers.Integral,)):
+        if not isinstance(
+            subdomain_id,
+            (
+                str,
+                numbers.Integral,
+            ),
+        ):
             raise ValueError("Expecting integer or string domain id.")
 
         # If we don't have an integration domain, try to find one in
@@ -381,19 +417,23 @@ class Measure(object):
         if domain is None:
             domains = extract_domains(integrand)
             if len(domains) == 1:
-                domain, = domains
+                (domain,) = domains
             elif len(domains) == 0:
                 raise ValueError("This integral is missing an integration domain.")
             else:
-                raise ValueError("Multiple domains found, making the choice of integration domain ambiguous.")
+                raise ValueError(
+                    "Multiple domains found, making the choice of integration domain ambiguous."
+                )
 
         # Otherwise create and return a one-integral form
-        integral = Integral(integrand=integrand,
-                            integral_type=self.integral_type(),
-                            domain=domain,
-                            subdomain_id=subdomain_id,
-                            metadata=self.metadata(),
-                            subdomain_data=self.subdomain_data())
+        integral = Integral(
+            integrand=integrand,
+            integral_type=self.integral_type(),
+            domain=domain,
+            subdomain_id=subdomain_id,
+            metadata=self.metadata(),
+            subdomain_data=self.subdomain_data(),
+        )
         return Form([integral])
 
 
