@@ -5,15 +5,12 @@
 #
 # SPDX-License-Identifier:    LGPL-3.0-or-later
 
-from ufl.core.ufl_type import ufl_type
 from ufl.core.operator import Operator
 from ufl.core.terminal import FormArgument
+from ufl.core.ufl_type import ufl_type
 
 
-@ufl_type(num_ops=1,
-          is_index_free=True,
-          is_terminal_modifier=True,
-          is_in_reference_frame=True)
+@ufl_type(num_ops=1, is_index_free=True, is_terminal_modifier=True, is_in_reference_frame=True)
 class ReferenceValue(Operator):
     """Representation of the reference cell value of a form argument."""
 
@@ -28,7 +25,7 @@ class ReferenceValue(Operator):
     @property
     def ufl_shape(self):
         """Get the UFL shape."""
-        return self.ufl_operands[0].ufl_element().reference_value_shape()
+        return self.ufl_operands[0].ufl_element().reference_value_shape
 
     def evaluate(self, x, mapping, component, index_values, derivatives=()):
         """Get child from mapping and return the component asked for."""
