@@ -18,13 +18,16 @@ symbolic reasoning about the spaces in which finite elements lie.
 from functools import total_ordering
 from math import inf, isinf
 
+__all_classes__ = ["SobolevSpace", "DirectionalSobolevSpace"]
+
 
 @total_ordering
 class SobolevSpace(object):
     """Symbolic representation of a Sobolev space.
 
-    This implements a subset of the methods of a Python set so that finite elements and
-    other Sobolev spaces can be tested for inclusion.
+    This implements a subset of the methods of a Python set so that
+    finite elements and other Sobolev spaces can be tested for
+    inclusion.
     """
 
     def __init__(self, name, parents=None):
@@ -50,7 +53,7 @@ class SobolevSpace(object):
             "HCurl": 0,
             "HEin": 0,
             "HDivDiv": 0,
-            "DirectionalH": 0
+            "DirectionalH": 0,
         }[self.name]
 
     def __str__(self):
@@ -80,34 +83,23 @@ class SobolevSpace(object):
     def __contains__(self, other):
         """Implement `fe in s` where `fe` is a FiniteElement and `s` is a SobolevSpace."""
         if isinstance(other, SobolevSpace):
-            raise TypeError("Unable to test for inclusion of a "
-                            "SobolevSpace in another SobolevSpace. "
-                            "Did you mean to use <= instead?")
-        return other.sobolev_space() == self or self in other.sobolev_space().parents
+            raise TypeError(
+                "Unable to test for inclusion of a SobolevSpace in another SobolevSpace. "
+                "Did you mean to use <= instead?"
+            )
+        return other.sobolev_space == self or self in other.sobolev_space.parents
 
     def __lt__(self, other):
         """In common with intrinsic Python sets, < indicates "is a proper subset of"."""
         return other in self.parents
 
-    def __call__(self, element):
-        """Syntax shortcut to create a HDivElement or HCurlElement."""
-        if self.name == "HDiv":
-            from ufl.finiteelement import HDivElement
-            return HDivElement(element)
-        elif self.name == "HCurl":
-            from ufl.finiteelement import HCurlElement
-            return HCurlElement(element)
-        raise NotImplementedError(
-            "SobolevSpace has no call operator (only the specific HDiv and HCurl instances)."
-        )
-
 
 @total_ordering
 class DirectionalSobolevSpace(SobolevSpace):
     """Directional Sobolev space.
 
     Symbolic representation of a Sobolev space with varying smoothness
-    in differerent spatial directions.
+    in different spatial directions.
     """
 
     def __init__(self, orders):
@@ -119,8 +111,8 @@ class DirectionalSobolevSpace(SobolevSpace):
                 smoothness requirement is enforced.
         """
         assert all(
-            isinstance(x, int) or isinf(x)
-            for x in orders), "Order must be an integer or infinity."
+            isinstance(x, int) or isinf(x) for x in orders
+        ), "Order must be an integer or infinity."
         name = "DirectionalH"
         parents = [L2]
         super(DirectionalSobolevSpace, self).__init__(name, parents)
@@ -135,14 +127,19 @@ class DirectionalSobolevSpace(SobolevSpace):
         return spaces[self._orders[spatial_index]]
 
     def __contains__(self, other):
-        """Implement `fe in s` where `fe` is a FiniteElement and `s` is a DirectionalSobolevSpace."""
+        """Check if one space is contained in another.
+
+        Implement `fe in s` where `fe` is a FiniteElement and `s` is a
+        DirectionalSobolevSpace.
+        """
         if isinstance(other, SobolevSpace):
-            raise TypeError("Unable to test for inclusion of a "
-                            "SobolevSpace in another SobolevSpace. "
-                            "Did you mean to use <= instead?")
-        return (other.sobolev_space() == self or all(
-            self[i] in other.sobolev_space().parents
-            for i in self._spatial_indices))
+            raise TypeError(
+                "Unable to test for inclusion of a SobolevSpace in another SobolevSpace. "
+                "Did you mean to use <= instead?"
+            )
+        return other.sobolev_space == self or all(
+            self[i] in other.sobolev_space.parents for i in self._spatial_indices
+        )
 
     def __eq__(self, other):
         """Check equality."""
@@ -155,8 +152,7 @@ class DirectionalSobolevSpace(SobolevSpace):
         if isinstance(other, DirectionalSobolevSpace):
             if self._spatial_indices != other._spatial_indices:
                 return False
-            return any(self._orders[i] > other._orders[i]
-                       for i in self._spatial_indices)
+            return any(self._orders[i] > other._orders[i] for i in self._spatial_indices)
 
         if other in [HDiv, HCurl]:
             return all(self._orders[i] >= 1 for i in self._spatial_indices)
@@ -164,8 +160,7 @@ class DirectionalSobolevSpace(SobolevSpace):
             # Don't know how these spaces compare
             return NotImplementedError(f"Don't know how to compare with {other.name}")
         else:
-            return any(
-                self._orders[i] > other._order for i in self._spatial_indices)
+            return any(self._orders[i] > other._order for i in self._spatial_indices)
 
     def __str__(self):
         """Format as a string."""
