@@ -22,7 +22,7 @@ def topological_sorting(nodes, edges):
         for es in edges.values():
             if node in es and node in S:
                 S.remove(node)
-                continue
+                break
 
     while S:
         node = S.pop(0)
@@ -48,10 +48,12 @@ def sorted_by_count(seq):
 
 def sorted_by_key(mapping):
     """Sort dict items by key, allowing different key types."""
+
     # Python3 doesn't allow comparing builtins of different type,
     # therefore the typename trick here
     def _key(x):
         return (type(x[0]).__name__, x[0])
+
     return sorted(mapping.items(), key=_key)
 
 
@@ -80,9 +82,13 @@ def canonicalize_metadata(metadata):
             value = canonicalize_metadata(value)
         elif isinstance(value, (int, float, str)) or value is None:
             value = str(value)
+        elif hasattr(value, "ufl_signature"):
+            value = value.ufl_signature
         else:
-            warnings.warn(f"Applying str() to a metadata value of type {type(value).__name__}, "
-                          "don't know if this is safe.")
+            warnings.warn(
+                f"Applying str() to a metadata value of type {type(value).__name__}, "
+                "don't know if this is safe."
+            )
             value = str(value)
         newvalues.append(value)
 
